# Logical Query Protocol

The Python code to interact with the LQP protobuf representation here has been
auto-generated from https://github.com/RelationalAI/logical-query-protocol, following the
instructions there.